# Protobufs

`model-mesh.proto` and `model-runtime.proto` are copied from https://github.com/kserve/modelmesh/tree/main/src/main/proto/current

-   They could potentially be submoduled in the future
-   `model_mesh_*.py` and `model_runtime_*.py` files are compiled from these

`process.proto` is the Model Train proto.

-   `process_*.py` file are compiled from this
